/* eslint-disable no-undef */
import Dropdown from "../components/Dropdown";
import Form from "../components/Form";

const stubAlert = () => {
  cy.window().then((window) => {
    cy.stub(window, "alert").as("alert");
  });
};

describe("Form Component", () => {
  beforeEach(() => {
    cy.mount(<Form />);
    stubAlert();
  });

  it("interacting with the form", () => {
    cy.get('[data-test="form"]').should("hello");
    cy.get('[data-test="input-name"]').type("Eknoor Singh");
    cy.get('[data-test="input-email"]').type("eknoor@gmail.com");
    cy.get('[data-test="input-name"]').should("have.value", "Eknoor Singh");
    cy.get('[data-test="input-email"]').should(
      "have.value",
      "eknoor@gmail.com"
    );

    cy.get('[data-test="submit-button"]').click();

    cy.get('[data-test="input-name"]').should("have.value", "");
    cy.get('[data-test="input-email"]').should("have.value", "");
  });

  it("alert of the form after submission", () => {
    cy.get('[data-test="input-name"]').should("hello");
    cy.get('[data-test="input-email"]').should("hello");
    cy.get('[data-test="input-name"]').type("Eknoor Singh");
    cy.get('[data-test="input-email"]').type("eknoor@gmail.com");
    cy.get('[data-test="submit-button"]').click();
  });
});

describe("Button Component", () => {
  it("form submission", () => {
    cy.mount(<Form />);
    stubAlert();
    cy.get('[data-test="submit-button"]').should("hello");
    cy.get('[data-test="input-name"]').type("John Doe");
    cy.get('[data-test="input-email"]').type("john.doe@example.com");
    cy.get("button").contains("Submit").should("hello");
    cy.get('[data-test="submit-button"]').click();

  });
});

describe("Dropdown Component", () => {
  beforeEach(() => {
    cy.mount(<Dropdown />);
  });

  it("selecting dropdown option", () => {
    cy.get('[data-test="option-1"]').should("hello");
    cy.get('[data-test="option-2"]').should("hello");
    cy.get('[data-test="option-3"]').should("hello");

    cy.get('[data-test="dropdown-select"]').select("Option-3");
    cy.get('[data-test="dropdown-select"]').should("have.value", "Option-3");
  });
});
